==> haskell-missingh-1.6.0.2-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MissingH
version:              1.6.0.2
visibility:           public
id:                   MissingH-1.6.0.2-8Ylegy67BQTBRA8n3EHKUI
key:                  MissingH-1.6.0.2-8Ylegy67BQTBRA8n3EHKUI
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2018 John Goerzen
maintainer:           Andreas Abel
author:               John Goerzen
synopsis:             Large utility library
description:
    @MissingH@ is a library of all sorts of utility functions for Haskell
    programmers.  It is written in pure Haskell and thus should be
    extremely portable and easy to use.

category:             Unclassified
abi:                  5979d0296932542e8e747df43fb63066
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/MissingH-1.6.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MissingH-1.6.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MissingH-1.6.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-missingh
hs-libraries:         HSMissingH-1.6.0.2-8Ylegy67BQTBRA8n3EHKUI
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hslogger-1.3.1.2-DouaEh2Olyj7S79Lig3W67 mtl-2.2.2
    network-3.1.4.0-HNOpCulLIRrH0UV3cvGeTA
    network-bsd-2.8.1.0-2j2ZbQwL2ho7OZpxXWFm02
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 parsec-3.1.16.1
    process-1.6.18.0 regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    time-1.12.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html:         /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-missingh-1.6.0.2-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MissingH
version:              1.6.0.2
visibility:           public
id:                   MissingH-1.6.0.2-7pCbnYA8cKW7fop7BwS1fR
key:                  MissingH-1.6.0.2-7pCbnYA8cKW7fop7BwS1fR
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2018 John Goerzen
maintainer:           Andreas Abel
author:               John Goerzen
synopsis:             Large utility library
description:
    @MissingH@ is a library of all sorts of utility functions for Haskell
    programmers.  It is written in pure Haskell and thus should be
    extremely portable and easy to use.

category:             Unclassified
abi:                  0468520dd829e93da7f74740b916ab8c
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/MissingH-1.6.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MissingH-1.6.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MissingH-1.6.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-missingh
hs-libraries:         HSMissingH-1.6.0.2-7pCbnYA8cKW7fop7BwS1fR
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hslogger-1.3.1.2-7cQcJPLUXZcJJrv1fX8vXI mtl-2.2.2
    network-3.1.4.0-ItBhIFDvz12FCCKfYobIMX
    network-bsd-2.8.1.0-AFh2WFCoL5pHjaTZ9bNOdj
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 parsec-3.1.16.1
    process-1.6.18.0 regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    time-1.12.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html:         /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
